/*
 * Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

package main

import (
	"flag"
	"os"
	"ssa/mod_analyst/pkg/db"
)

func main() {
	// user args
	var user_info db.UserInfo
	var is_remove bool

	// DB connection args
	var db_info db.DbInfo

	// Get user properties
	flag.BoolVar(&user_info.Is_aod, "aod", false, "When adding a user, makes them part of the AOD group (by default they are added to the DA group)")
	flag.StringVar(&user_info.Name, "name", "", "The full name of the DA/AOD to be added, use quotes for the first and last name (e.g. -name 'First Last')")
	flag.StringVar(&user_info.Email, "email", "", "The email of the DA/AOD to be added")
	flag.BoolVar(&is_remove, "rm", false, "Remove the user from the database")

	// Get DB connection args
	flag.BoolVar(&db_info.Is_ssl, "ssl", false, "Use ssl for the database connection")
	flag.IntVar(&db_info.Port, "port", 5432, "The port for the database")
	flag.StringVar(&db_info.Dbname, "dbname", "archive", "The name of the database to connect to")
	flag.StringVar(&db_info.Host, "host", os.Getenv("HOSTNAME"), "The host where the database is located")
	flag.StringVar(&db_info.Property_path, "prop", "/home/casa/capo/${CAPO_PROFILE}.properties", "Path to the properties file with the login details for the database")
	flag.Parse()

	// Make sure name is given
	if len(user_info.Name) == 0 {
		flag.Usage()
		return
	}

	if is_remove {
		db.RemoveUser(user_info, db_info)
	} else {
		db.AddUser(user_info, db_info)
	}
}
