#!/usr/bin/env bash
#
#  A file to investigate a directory and create an SECI imaging
#  artifacts tar file, then stage files for ingestion
#  into NGAS. Adapted from AAT-PPI for Workspaces use
#
#  Arguments:
#       1: The path to the VLASS SECI Cache Area
#       1: The cache directory name
#       2: The staging directory root path
#       3: A name for the artifacts file
#
set -o errexit -o nounset -o xtrace

CACHE_PATH=$1;shift
CACHE_DIR=$1;shift
STAGE_DIR=$1;shift
FILENAME=$1;shift

SOURCE_DIR=${CACHE_PATH}/${CACHE_DIR}

# Create the staging directory carefully:
mkdir -p ${STAGE_DIR}/${CACHE_DIR}


# SECI weblogs are already bundled up, no need to recreate the tar
# The weblog may have a prefix, so account for that:
/bin/cp -f ${SOURCE_DIR}/*weblog.tgz ${STAGE_DIR}/${CACHE_DIR}
# NOTE: This fails if we have no weblog

#
# Move reimaging_resources tar to staging area
#
/bin/cp -f ${SOURCE_DIR}/*reimaging_resources.tgz ${STAGE_DIR}/${CACHE_DIR}

#
# Prepare the artifacts file, we'll collect everything to be ingested in a directory.
#
if [[ -e ${STAGE_DIR}/${CACHE_DIR}/${FILENAME}.tar ]]
then
    echo "Artifacts Tar File Already Exists!  Removing the file for recreation"
    /bin/rm -f ${STAGE_DIR}/${CACHE_DIR}/${FILENAME}.tar
fi

# tar a subset of files into a tar archive in the storage path
#   Skipped: CSV files, FITS files, Weblog, and Re-imaging Resources
#
tar --exclude=\*.csv --exclude=\*.fits --exclude=pipeline-\* --exclude=*reimaging_resources.tgz --exclude=*weblog.tgz -C${SOURCE_DIR} -cvf ${STAGE_DIR}/${CACHE_DIR}/${FILENAME}.tar .
if [[ $? -ne 0 ]]
then
    echo "Creation of pipeline artifacts tar file failed, exiting"
    exit -1
fi


# Now link the FITS files over to the staging directory (Create hard link, and be insistent)
#
# We just want the file name, so we'll work in the source directory
pushd ${SOURCE_DIR}
# link the files
for fitsFile in $(ls -t *.fits);do cp ${SOURCE_DIR}/${fitsFile} ${STAGE_DIR}/${CACHE_DIR};done
for csvFile in $(ls -t *.csv);do cp ${SOURCE_DIR}/${csvFile} ${STAGE_DIR}/${CACHE_DIR};done
# move back to the working directory
popd
